Database

Struct Database 

pub struct Database { /* private fields */ }
Database connection wrapper with connection pool

Implementations

Source

impl Database

pub fn db_path() -> PathBuf

Get the database path that will be used

pub fn new(path: &str) -> Result<Self>

Create a new database at a custom path

pub fn open() -> Result<Self>

Open database at default path (respects DECIDUOUS_DB_PATH env var)

pub fn open_at<P: AsRef<Path>>(path: P) -> Result<Self>

Open database at specified path

pub fn migrate_add_change_ids(&self) -> Result<bool>

Migrate existing database to add change_id columns if missing

pub fn create_node( &self, node_type: &str, title: &str, description: Option<&str>, confidence: Option<u8>, commit: Option<&str>, ) -> Result<i32>

Create a new decision node

pub fn create_node_full( &self, node_type: &str, title: &str, description: Option<&str>, confidence: Option<u8>, commit: Option<&str>, prompt: Option<&str>, files: Option<&str>, branch: Option<&str>, created_at: Option<&str>, ) -> Result<i32>

Create a decision node with full metadata (including prompt and files)

pub fn add_node( &self, node_type: &str, title: &str, description: Option<&str>, confidence: Option<u8>, commit: Option<&str>, ) -> Result<i32>

Add a node (alias for create_node for doc examples)

pub fn create_node_with_change_id( &self, change_id: &str, node_type: &str, title: &str, description: Option<&str>, confidence: Option<u8>, commit: Option<&str>, prompt: Option<&str>, files: Option<&str>, branch: Option<&str>, ) -> Result<i32>

Create a node with a specific change_id (for patch application)

pub fn create_edge( &self, from_id: i32, to_id: i32, edge_type: &str, rationale: Option<&str>, ) -> Result<i32>

Create an edge between nodes

pub fn add_edge( &self, from_id: i32, to_id: i32, edge_type: &str, rationale: Option<&str>, ) -> Result<i32>

Add an edge (alias for create_edge for doc examples)

pub fn delete_edge(&self, from_id: i32, to_id: i32) -> Result<()>

Delete an edge between two nodes

pub fn delete_node(&self, node_id: i32, dry_run: bool) -> Result<DeleteSummary>

Delete a node and all its connected edges

pub fn update_node_status(&self, node_id: i32, status: &str) -> Result<()>

Update node status

pub fn update_node_commit(&self, node_id: i32, commit_hash: &str) -> Result<()>

Update a node’s commit hash in metadata_json

pub fn update_node_prompt(&self, node_id: i32, prompt: &str) -> Result<()>

Update a node’s prompt in metadata_json

pub fn get_all_nodes(&self) -> Result<Vec<DecisionNode>>

Get all nodes

pub fn get_all_edges(&self) -> Result<Vec<DecisionEdge>>

Get all edges

pub fn get_node(&self, node_id: i32) -> Result<Option<DecisionNode>>

Get a single node by ID

pub fn get_node_children(&self, node_id: i32) -> Result<Vec<DecisionNode>>

Get children of a node (outgoing edges)

pub fn get_node_parents(&self, node_id: i32) -> Result<Vec<DecisionNode>>

Get parents of a node (incoming edges)

pub fn get_graph(&self) -> Result<DecisionGraph>

Get full graph as JSON-serializable structure

pub fn get_graph_with_config( &self, config: Option<Config>, ) -> Result<DecisionGraph>

Get full graph with config included (for export)

pub fn log_command( &self, command: &str, description: Option<&str>, working_dir: Option<&str>, ) -> Result<i32>

Log a command execution

pub fn complete_command( &self, log_id: i32, exit_code: i32, stdout: Option<&str>, stderr: Option<&str>, duration_ms: i32, ) -> Result<()>

Complete a command log entry

pub fn get_recent_commands(&self, limit: i64) -> Result<Vec<CommandLog>>

Get recent commands

pub fn create_roadmap_item( &self, title: &str, description: Option<&str>, section: Option<&str>, parent_id: Option<i32>, checkbox_state: &str, ) -> Result<i32>

Create a new roadmap item

pub fn create_roadmap_item_full( &self, change_id: &str, title: &str, description: Option<&str>, section: Option<&str>, parent_id: Option<i32>, checkbox_state: &str, github_issue_number: Option<i32>, github_issue_state: Option<&str>, outcome_node_id: Option<i32>, outcome_change_id: Option<&str>, markdown_line_start: Option<i32>, markdown_line_end: Option<i32>, content_hash: Option<&str>, ) -> Result<i32>

Create a roadmap item with full metadata (for sync operations)

pub fn get_all_roadmap_items(&self) -> Result<Vec<RoadmapItem>>

Get all roadmap items

pub fn clear_roadmap_items(&self) -> Result<usize>

Clear all roadmap items (for refresh)

pub fn get_roadmap_items_by_section( &self, section: &str, ) -> Result<Vec<RoadmapItem>>

Get roadmap items by section

pub fn get_roadmap_item_by_change_id( &self, change_id: &str, ) -> Result<Option<RoadmapItem>>

Get a roadmap item by change_id

pub fn update_roadmap_item_github( &self, item_id: i32, issue_number: Option<i32>, issue_state: Option<&str>, ) -> Result<()>

Update a roadmap item’s GitHub issue info

pub fn update_roadmap_item_github_by_title( &self, title: &str, issue_number: i32, issue_state: &str, ) -> Result<()>

Update a roadmap item’s GitHub issue info by finding it by title (first match)

pub fn update_roadmap_item_github_by_change_id( &self, change_id: &str, issue_number: i32, issue_state: &str, ) -> Result<()>

Update a roadmap item’s GitHub issue info by change_id (unique key)

Link a roadmap item to a decision graph outcome node

Unlink a roadmap item from its outcome node

pub fn update_roadmap_item_checkbox( &self, item_id: i32, checkbox_state: &str, ) -> Result<()>

Update a roadmap item’s checkbox state

pub fn update_roadmap_item_synced(&self, item_id: i32) -> Result<()>

Update last synced timestamp for a roadmap item

pub fn get_roadmap_sync_state( &self, roadmap_path: &str, ) -> Result<Option<RoadmapSyncState>>

Get roadmap sync state (returns None if not initialized)

pub fn get_or_create_sync_state( &self, roadmap_path: &str, ) -> Result<RoadmapSyncState>

Get or create roadmap sync state

pub fn update_sync_state( &self, state_id: i32, content_hash: Option<&str>, github_repo: Option<&str>, github_synced: bool, markdown_parsed: bool, conflict_count: i32, ) -> Result<()>

Update sync state after a sync operation

pub fn create_roadmap_conflict( &self, item_change_id: &str, conflict_type: &str, local_value: Option<&str>, remote_value: Option<&str>, ) -> Result<i32>

Create a conflict record

pub fn get_unresolved_conflicts(&self) -> Result<Vec<RoadmapConflict>>

Get all unresolved conflicts

pub fn resolve_roadmap_conflict( &self, conflict_id: i32, resolution: &str, ) -> Result<()>

Resolve a conflict

pub fn delete_roadmap_item(&self, item_id: i32) -> Result<()>

Delete a roadmap item by ID

pub fn check_roadmap_item_completion( &self, item_id: i32, ) -> Result<(bool, bool, bool)>

Check if a roadmap item is complete (has outcome AND issue closed)

pub fn cache_github_issue( &self, issue_number: i32, repo: &str, title: &str, body: Option<&str>, state: &str, html_url: &str, created_at: &str, updated_at: &str, ) -> Result<()>

Cache a GitHub issue for local display in TUI/Web

pub fn get_cached_issue( &self, repo: &str, issue_number: i32, ) -> Result<Option<GitHubIssueCache>>

Get a cached GitHub issue by repo and number

pub fn get_cached_issues_for_repo( &self, repo: &str, ) -> Result<Vec<GitHubIssueCache>>

Get all cached issues for a repo

pub fn get_all_cached_issues(&self) -> Result<Vec<GitHubIssueCache>>

Get all cached issues

pub fn clear_stale_cache(&self, max_age_hours: i64) -> Result<usize>

Clear cached issues older than a specified duration

Source

impl Database

pub fn export_patch( &self, node_ids: Option<Vec<i32>>, branch_filter: Option<&str>, author: Option<String>, base_commit: Option<String>, ) -> Result<GraphPatch, DbError>

Export nodes and edges as a patch

pub fn apply_patch( &self, patch: &GraphPatch, dry_run: bool, ) -> Result<ApplyResult, DbError>

Apply a patch to the database