Export utilities for decision graphs
Provides DOT graph export and PR writeup generation.
Structs
- DotConfig
- Configuration for DOT export
- Writeup
Config - Configuration for PR writeup generation
Functions
- filter_
graph_ by_ ids - Filter a graph to only include specific node IDs (no traversal)
- filter_
graph_ from_ roots - Filter a graph to only include nodes reachable from given root IDs
- generate_
pr_ writeup - Generate a PR writeup from a decision graph
- graph_
to_ dot - Convert a decision graph to DOT format
- parse_
node_ range - Parse a node range specification (e.g., “1-11” or “1,2,5-10,15”)